# `narwhals.dtypes`

::: narwhals.dtypes
    handler: python
    options:
      members:
        - Int64
        - Int32
        - Int16
        - Int8
        - UInt64
        - UInt32
        - UInt16
        - UInt8
        - Float64
        - Float32
        - Boolean
        - String
        - Datetime
      show_root_heading: false
      show_source: false
      show_bases: false
